==> AbyssinicaSIL-2.200.zip: AbyssinicaSIL-2.200/documentation/source/sample.md <==
---
title: Abyssinica SIL - Type Sample
fontversion: 2.200
---

This document demonstrates all of the characters in the font. It is organized by Unicode block. Alternate glyphs that are available through features are demonstrated in the [Features](features.md) document. At the end is a sample demonstrating an example of running text.

## Type Sample

### Basic Latin:

<span class='abyssinica-R normal'>!"#$%&'()*+,./0123456789:;=>?@ ABCDEFGHIJKLMNOPQRSTUVWWYZ[\]^` abcdefghijklmnopqrstuvwxyz{|}~</span>
	

### Latin-1 Supplement:

<span class='abyssinica-R normal'> ¡¢£¤¥¦§¨©ª«¬­®¯°±²³´µ¶·¸¹º»¼½¾¿ ÀÁÂÃÄÅÆÇÈÉÊËÌÍÎÏÐÑÒÓÔÕÖ×ØÙÚÛÜÝÞß àáâãäåæçèéêëìíîïðñòóôõö÷øùúûüýþÿ</span>

### Latin Extended-A:

<span class='abyssinica-R normal'>ıŒœŠšŸŽž</span>

### Latin Extended-B:

<span class='abyssinica-R normal'>ƒ</span>

### Spacing Modifier Letters:

<span class='abyssinica-R normal'>ˆ ˇ ː ˘ ˙ ˚ ˛ ˜ ˝</span>

### Combining Diacritical Marks:

<span class='abyssinica-R normal'>◌̀◌́◌̂◌̃◌̄◌̇◌̈◌̋◌̌◌̏ CGJ (U+034F)</br>
ሆ̀ሆ́ሆ̂ሆ̃ሆ̄ሆ̇ሆ̈ሆ̋ሆ̌ሆ̏</span>


### Greek and Coptic:

<span class='abyssinica-R normal'> π </span>

### General Punctuation:

<span class='abyssinica-R normal'>    –—‘’‚“”„†‡•…‰‹›※⁄⁠</span>

### Superscripts and Subscripts
<span class='abyssinica-R normal'>⁰⁴⁵⁶⁷⁸⁹</span>


### Currency Symbols:

<span class='abyssinica-R normal'> €</span>

### Letterlike Symbols, Mathematical Operators, Control Pictures, Geometric Shapes, Dingbats: 

<span class='abyssinica-R normal'>™Ω ∂∅∆∏∑∙√∞∫≈≠≤≥ ␣ ◊ ◌ ✓</span>

### Ethiopic:

#### Syllables:

<span class='abyssinica-R normal'>ሀሁሂሃሄህሆሇ ለሉሊላሌልሎሏ ሐሑሒሓሔሕሖሗ መሙሚማሜምሞሟ ሠሡሢሣሤሥሦሧ ረሩሪራሬርሮሯ ሰሱሲሳሴስሶሷ ሸሹሺሻሼሽሾሿ ቀቁቂቃቄቅቆቇ ቈቊቋቌቍ ቐቑቒቓቔቕ ቖቘቚቛቜቝ በቡቢባቤብቦቧ ቨቩቪቫቬቭቮቯ ተቱቲታቴትቶቷ ቸቹቺቻቼችቾቿ ኀኁኂኃኄኅኆኇ ኈኊኋኌኍ ነኑኒናኔንኖኗ ኘኙኚኛኜኝኞኟ አኡኢኣኤእኦ ኧከኩኪካኬክኮኯ ኰኲኳኴኵ ኸኹኺኻኼኽኾዀዂዃዄዅ ወዉዊዋዌውዎዏ ዐዑዒዓዔዕዖ ዘዙዚዛዜዝዞዟ ዠዡዢዣዤዥዦዧ የዩዪያዬይዮዯ ደዱዲዳዴድዶዷ ዸዹዺዻዼዽዾዿ ጀጁጂጃጄጅጆጇ ገጉጊጋጌግጎጏጐጒጓጔጕ ጘጙጚጛጜጝጞጟ ጠጡጢጣጤጥጦጧ ጨጩጪጫጬጭጮጯ ጰጱጲጳጴጵጶጷ ጸጹጺጻጼጽጾጿ ፀፁፂፃፄፅፆፇ ፈፉፊፋፌፍፎፏ ፐፑፒፓፔፕፖፗ ፘ ፙ ፚ</span>

#### Combining Marks
<span class='abyssinica-R normal'>◌፞◌፟◌፝</br>
ሆ፞ሆ፟ሆ፝</span>

#### Punctuation
<span class='abyssinica-R normal'>፠፡።፣፤፥፦፧፨</span>

#### Digits
<span class='abyssinica-R normal'>፩፪፫፬፭፮፯፰፱</span>

#### Numbers
<span class='abyssinica-R normal'>፲፳፴፵፶፷፸፹፺፻፼</span>

### Ethiopic Supplement

#### Syllables for Gurage
<span class='abyssinica-R normal'>ᎀᎁᎂᎃᎄᎅᎆᎇᎈᎉᎊᎋᎌᎍᎎᎏ</span>

#### Tonal Marks
<span class='abyssinica-R normal'>᎐ ᎑ ᎒ ᎓ ᎔ ᎕ ᎖ ᎗ ᎘ ᎙</span>


### Ethiopic Extended

#### Syllables for Me’en
<span class='abyssinica-R normal'>ⶀⶁⶂⶃⶄⶅⶆⶇⶈⶉⶊⶋⶌⶍⶎⶏⶐⶑⶒ</span>

#### Syllables for Blin
<span class='abyssinica-R normal'>ⶓⶔⶕⶖ</span>

#### Syllables for Gurage
<span class='abyssinica-R normal'>ⶠⶡⶢⶣⶤⶥⶦ ⶨⶩⶪⶫⶬⶭⶮ ⶰⶱⶲⶳⶴⶵⶶ ⶸⶹⶺⶻⶼⶽⶾ ⷀⷁⷂⷃⷄⷅⷆ ⷈⷉⷊⷋⷌⷍⷎ ⷐⷑⷒⷓⷔⷕⷖ ⷘⷙⷚⷛⷜⷝⷞ</span>

### Ethiopic Extended-A

#### Gamo-Gofa-Dawro and Basketo
<span class='abyssinica-R normal'>ꬁꬂꬃꬄꬅꬆ ꬉꬊꬋꬌꬍꬎ</span>

#### Gamo-Gofa-Dawro
<span class='abyssinica-R normal'>ꬑꬒꬓꬔꬕꬖ </span>

#### Gumuz
<span class='abyssinica-R normal'>ꬠꬡꬢꬣꬤꬥꬦ ꬨꬩꬪꬫꬬꬭꬮ</span>

### Ethiopic Extended-B

#### Syllables for Gurage
<span class='abyssinica-R normal'>𞟠𞟡𞟢𞟣𞟤𞟥𞟦 𞟨𞟩𞟪𞟫 𞟭𞟮 𞟰𞟱𞟲 𞟳𞟴𞟵𞟶𞟷 𞟸𞟹𞟺 𞟻𞟼 𞟽𞟾</span>


## Sample Text

### Amharic UDHR #26:

<span class='abyssinica-R normal'>እያንዳንዱ፡ሰው፡የመማር፡መብት፡አለው።፡ትምህርት፡ቢያንስ፡ቢያንስ፡በአንደኛ፡ደረጃና፡በመሰረታዊ፡ደረጃዎች፡በነጻ፡ሊሆን፡ይገባል።፡የአንደኛ፡ደረጃ፡ትምህርት፡መማር፡ግዴታ፡ነው።፡የቴክኒክና፡የልዩ፡ልዩ፡ሙያ፡ትምህርት፡በጠቅላላው፡የከፍተኛ፡ደረጃ፡ደግሞ፡በችሎታ፡መሠረት፡ለሁሉም፡እኩል፡መሰጠት፡አለበት።</span>

<span class='abyssinica-R normal'>ትምህርት፡ለእያንዳንዱ፡ሰው፡ሁኔታ፡ማሻሻያና፡ለሰብዓዊ፡መብቶችም፡መሠረታዊ፡ነጻነቶች፡ክብር፡ማዳበርያ፡የሚውል፡መሆን፡አለበት።፡እንዲሁም፡የተለያየ፡ዘር፡ወይም፡ሃይማኖት፡ባሏቸው፡ሕዝቦች፡መካከል፡ሁሉ፡መግባባትን፡ተቻችሎ፡የመኖርንና፡የመተባበርን፡መንፈስ፡የሚያጠነክርና፡የተባበሩት፡መንግሥታት፡ድርጅት፡ሰላምን፡ለመጠበቅ፡የሚፈጽማቸው፡ተግባሮች፡እንዲስፋፋ፡የሚያበረታቱ፡መሆን፡አለበት።፡</span>

<span class='abyssinica-R normal'>ወላጆች፡ለልጆቻቸው፡ለመስጠት፡የሚፈልጉትን፡ትምህርት፡ለመምረጥ፡የቅድሚያ፡መብት፡አላችው።፡</span>



<!-- PRODUCT SITE ONLY
[font id='abyssinica-R' face='AbyssinicaSIL-Regular' size='150%']
-->

==> AbyssinicaSIL-2.201.zip: AbyssinicaSIL-2.201/documentation/source/sample.md <==
---
title: Abyssinica SIL - Type Sample
fontversion: 2.201
---

This document demonstrates all of the characters in the font. It is organized by Unicode block. Alternate glyphs that are available through features are demonstrated in the [Features](features.md) document. At the end is a sample demonstrating an example of running text.

### Basic Latin:

<span class='abyssinica-R normal'>!"#$%&'()*+,./0123456789:;=>?@ ABCDEFGHIJKLMNOPQRSTUVWWYZ[\]^` abcdefghijklmnopqrstuvwxyz{|}~</span>
	

### Latin-1 Supplement:

<span class='abyssinica-R normal'> ¡¢£¤¥¦§¨©ª«¬­®¯°±²³´µ¶·¸¹º»¼½¾¿ ÀÁÂÃÄÅÆÇÈÉÊËÌÍÎÏÐÑÒÓÔÕÖ×ØÙÚÛÜÝÞß àáâãäåæçèéêëìíîïðñòóôõö÷øùúûüýþÿ</span>

### Latin Extended-A:

<span class='abyssinica-R normal'>ıŒœŠšŸŽž</span>

### Latin Extended-B:

<span class='abyssinica-R normal'>ƒ</span>

### Spacing Modifier Letters:

<span class='abyssinica-R normal'>ˆ ˇ ː ˘ ˙ ˚ ˛ ˜ ˝</span>

### Combining Diacritical Marks:

<span class='abyssinica-R normal'>◌̀◌́◌̂◌̃◌̄◌̇◌̈◌̋◌̌◌̏ CGJ (U+034F)</br>
ሆ̀ሆ́ሆ̂ሆ̃ሆ̄ሆ̇ሆ̈ሆ̋ሆ̌ሆ̏</span>


### Greek and Coptic:

<span class='abyssinica-R normal'> π </span>

### General Punctuation:

<span class='abyssinica-R normal'>    –—‘’‚“”„†‡•…‰‹›※⁄⁠</span>

### Superscripts and Subscripts
<span class='abyssinica-R normal'>⁰⁴⁵⁶⁷⁸⁹</span>


### Currency Symbols:

<span class='abyssinica-R normal'> €</span>

### Letterlike Symbols, Mathematical Operators, Control Pictures, Geometric Shapes, Dingbats: 

<span class='abyssinica-R normal'>™Ω ∂∅∆∏∑∙√∞∫≈≠≤≥ ␣ ◊ ◌ ✓</span>

### Ethiopic:

#### Syllables:

<span class='abyssinica-R normal'>ሀሁሂሃሄህሆሇ ለሉሊላሌልሎሏ ሐሑሒሓሔሕሖሗ መሙሚማሜምሞሟ ሠሡሢሣሤሥሦሧ ረሩሪራሬርሮሯ ሰሱሲሳሴስሶሷ ሸሹሺሻሼሽሾሿ ቀቁቂቃቄቅቆቇ ቈቊቋቌቍ ቐቑቒቓቔቕ ቖቘቚቛቜቝ በቡቢባቤብቦቧ ቨቩቪቫቬቭቮቯ ተቱቲታቴትቶቷ ቸቹቺቻቼችቾቿ ኀኁኂኃኄኅኆኇ ኈኊኋኌኍ ነኑኒናኔንኖኗ ኘኙኚኛኜኝኞኟ አኡኢኣኤእኦ ኧከኩኪካኬክኮኯ ኰኲኳኴኵ ኸኹኺኻኼኽኾዀዂዃዄዅ ወዉዊዋዌውዎዏ ዐዑዒዓዔዕዖ ዘዙዚዛዜዝዞዟ ዠዡዢዣዤዥዦዧ የዩዪያዬይዮዯ ደዱዲዳዴድዶዷ ዸዹዺዻዼዽዾዿ ጀጁጂጃጄጅጆጇ ገጉጊጋጌግጎጏጐጒጓጔጕ ጘጙጚጛጜጝጞጟ ጠጡጢጣጤጥጦጧ ጨጩጪጫጬጭጮጯ ጰጱጲጳጴጵጶጷ ጸጹጺጻጼጽጾጿ ፀፁፂፃፄፅፆፇ ፈፉፊፋፌፍፎፏ ፐፑፒፓፔፕፖፗ ፘ ፙ ፚ</span>

#### Combining Marks
<span class='abyssinica-R normal'>◌፞◌፟◌፝</br>
ሆ፞ሆ፟ሆ፝</span>

#### Punctuation
<span class='abyssinica-R normal'>፠፡።፣፤፥፦፧፨</span>

#### Digits
<span class='abyssinica-R normal'>፩፪፫፬፭፮፯፰፱</span>

#### Numbers
<span class='abyssinica-R normal'>፲፳፴፵፶፷፸፹፺፻፼</span>

### Ethiopic Supplement

#### Syllables for Gurage
<span class='abyssinica-R normal'>ᎀᎁᎂᎃᎄᎅᎆᎇᎈᎉᎊᎋᎌᎍᎎᎏ</span>

#### Tonal Marks
<span class='abyssinica-R normal'>᎐ ᎑ ᎒ ᎓ ᎔ ᎕ ᎖ ᎗ ᎘ ᎙</span>


### Ethiopic Extended

#### Syllables for Me’en
<span class='abyssinica-R normal'>ⶀⶁⶂⶃⶄⶅⶆⶇⶈⶉⶊⶋⶌⶍⶎⶏⶐⶑⶒ</span>

#### Syllables for Blin
<span class='abyssinica-R normal'>ⶓⶔⶕⶖ</span>

#### Syllables for Gurage
<span class='abyssinica-R normal'>ⶠⶡⶢⶣⶤⶥⶦ ⶨⶩⶪⶫⶬⶭⶮ ⶰⶱⶲⶳⶴⶵⶶ ⶸⶹⶺⶻⶼⶽⶾ ⷀⷁⷂⷃⷄⷅⷆ ⷈⷉⷊⷋⷌⷍⷎ ⷐⷑⷒⷓⷔⷕⷖ ⷘⷙⷚⷛⷜⷝⷞ</span>

### Ethiopic Extended-A

#### Gamo-Gofa-Dawro and Basketo
<span class='abyssinica-R normal'>ꬁꬂꬃꬄꬅꬆ ꬉꬊꬋꬌꬍꬎ</span>

#### Gamo-Gofa-Dawro
<span class='abyssinica-R normal'>ꬑꬒꬓꬔꬕꬖ </span>

#### Gumuz
<span class='abyssinica-R normal'>ꬠꬡꬢꬣꬤꬥꬦ ꬨꬩꬪꬫꬬꬭꬮ</span>

### Ethiopic Extended-B

#### Syllables for Gurage
<span class='abyssinica-R normal'>𞟠𞟡𞟢𞟣𞟤𞟥𞟦 𞟨𞟩𞟪𞟫 𞟭𞟮 𞟰𞟱𞟲 𞟳𞟴𞟵𞟶𞟷 𞟸𞟹𞟺 𞟻𞟼 𞟽𞟾</span>


## Sample Text

### Amharic UDHR #26:

<span class='abyssinica-R normal'>እያንዳንዱ፡ሰው፡የመማር፡መብት፡አለው።፡ትምህርት፡ቢያንስ፡ቢያንስ፡በአንደኛ፡ደረጃና፡በመሰረታዊ፡ደረጃዎች፡በነጻ፡ሊሆን፡ይገባል።፡የአንደኛ፡ደረጃ፡ትምህርት፡መማር፡ግዴታ፡ነው።፡የቴክኒክና፡የልዩ፡ልዩ፡ሙያ፡ትምህርት፡በጠቅላላው፡የከፍተኛ፡ደረጃ፡ደግሞ፡በችሎታ፡መሠረት፡ለሁሉም፡እኩል፡መሰጠት፡አለበት።</span>

<span class='abyssinica-R normal'>ትምህርት፡ለእያንዳንዱ፡ሰው፡ሁኔታ፡ማሻሻያና፡ለሰብዓዊ፡መብቶችም፡መሠረታዊ፡ነጻነቶች፡ክብር፡ማዳበርያ፡የሚውል፡መሆን፡አለበት።፡እንዲሁም፡የተለያየ፡ዘር፡ወይም፡ሃይማኖት፡ባሏቸው፡ሕዝቦች፡መካከል፡ሁሉ፡መግባባትን፡ተቻችሎ፡የመኖርንና፡የመተባበርን፡መንፈስ፡የሚያጠነክርና፡የተባበሩት፡መንግሥታት፡ድርጅት፡ሰላምን፡ለመጠበቅ፡የሚፈጽማቸው፡ተግባሮች፡እንዲስፋፋ፡የሚያበረታቱ፡መሆን፡አለበት።፡</span>

<span class='abyssinica-R normal'>ወላጆች፡ለልጆቻቸው፡ለመስጠት፡የሚፈልጉትን፡ትምህርት፡ለመምረጥ፡የቅድሚያ፡መብት፡አላችው።፡</span>



<!-- PRODUCT SITE ONLY
[font id='abyssinica' face='AbyssinicaSIL-Regular' size='150%']
-->
